#!/usr/bin/env bash

set -euo pipefail

SCRIPT_DIR=$(dirname -- "${BASH_SOURCE[0]}")
TEMP_DIR=${SCRIPT_DIR}/.tmp
CERT_OUTDIR="${SCRIPT_DIR}/content/certs"
CI="${CI:-false}"

CERTIFICATES_BASE_URL=${CERTIFICATES_BASE_URL:-https://certificates.pki.siemens.cloud}
CERTIFICATE_BUNDLES="pki-public-bundle.crt ad-bundle.crt intermediate-bundle.crt zerotrust-bundle.crt plm-bundle.crt"

if ! command -v tar >/dev/null ||
	! command -v curl >/dev/null ||
	! command -v debchange >/dev/null ||
	! command -v install >/dev/null
then
	echo "This script requires the following packages: " >&2
	echo "coreutils curl devscripts tar" >&2
        exit 1
fi

function cleanup {
        rm -rf "${TEMP_DIR}"
}
trap cleanup EXIT
mkdir -p "${TEMP_DIR}"

for bundle in ${CERTIFICATE_BUNDLES}
do
	curl --ssl-reqd -fsSL -o "${TEMP_DIR}/${bundle}" "${CERTIFICATES_BASE_URL}/bundles/${bundle}"
	curl --ssl-reqd -fsSL -o "${TEMP_DIR}/${bundle}.sha256sum" "${CERTIFICATES_BASE_URL}/bundles/${bundle}.sha256sum"
done

pushd "${TEMP_DIR}"
sha256sum -c *.sha256sum
popd

rm -rf "${CERT_OUTDIR}"
mkdir -p "${CERT_OUTDIR}"

for bundle in ${CERTIFICATE_BUNDLES}
do
	install -m644 "${TEMP_DIR}/$bundle" -t ${CERT_OUTDIR}
done

if [[ -z $(git add --dry-run "${CERT_OUTDIR}") ]];
then
	echo "No changes in certificate bundles. Skipping update."
	exit 0
fi

# Create a tar.gz to be used for building the packages
tar -czf "${SCRIPT_DIR}/certs.tar.gz" -C "${CERT_OUTDIR}" .

export GIT_COMMITTER_NAME="Siemens mLinux"
export GIT_COMMITTER_EMAIL="mlinux.it@siemens.com"
export GIT_AUTHOR_NAME="${GIT_COMMITTER_NAME}"
export GIT_AUTHOER_EMAIL="${GIT_COMMITTER_EMAIL}"
export DEBFULLNAME="${GIT_COMMITTER_NAME}"
export DEBEMAIL="${GIT_COMMITTER_EMAIL}"
export DEBCHANGE_AUTO_NMU=no

# Bump the debian changelog and rpm spec
pushd "$(realpath ${SCRIPT_DIR}/../../../packages/siemens-certificates/siemens-certificates/)"
debchange -v "$(date +'%Y.%m.%d')" "update certificates"
debchange -r "" --distribution "unstable"

rpmdev-bumpspec \
	--new="$(date +'%Y.%m.%d')" \
	--userstring="${GIT_COMMITTER_NAME} <${GIT_COMMITTER_EMAIL}>" \
	--comment="update certificates" \
	./siemens-certificates.spec
popd

if [[ "${CI}" != "true" ]];
then
	echo "Running outside of CI. Skipping automated commit"
	exit 0
else
	echo "Committing and publishing changes."
fi

export ISO_DATE="$(date --iso-8601)"
export BRANCH_NAME="feat/source-update-${ISO_DATE}"

git config --global user.name "${GIT_COMMITTER_NAME}"
git config --global user.email "${GIT_COMMITTER_EMAIL}"

git remote set-url origin "https://project-token:${GITLAB_TOKEN}@${CI_SERVER_HOST}/${CI_PROJECT_PATH}.git"
git switch -C "${BRANCH_NAME}"
git add .
git commit -m "feat: source update ${ISO_DATE}"
git push -o merge_request.create -o merge_request.merge_when_pipeline_succeeds -f origin "${BRANCH_NAME}"
